@@ -2,7 +2,7 @@ package TestPersisterElsewhere;
 
 use strict;
 use warnings;
-use base qw( Workflow::Persister::DBI );
+use parent qw( Workflow::Persister::DBI );
 
 sub create_handle { return undef; }
 
